@@ -11,7 +11,13 @@ import traceback
 
 import cherrypy
 import dispatch
-import cElementTree as et
+try:
+#    # python 2.5 ?
+    from xml.etree import cElementTree as et
+except ImportError:
+#    # python 2.4 ? so try to get stand-alone version
+    import cElementTree as et
+
 from genshi.builder import tag, Element
 
 from turbogears import controllers, expose as tgexpose
