@@ -1,6 +1,6 @@
 # Release information about TGWebServices
 
-version = "1.1.2"
+version = "1.2.0"
 
 description = "Multiprotocol Web Services for TurboGears"
 long_description = """TurboGears gives you a plain HTTP with JSON return values API for your application for free. This isn't always what you want, though. Sometimes, you don't want to expose all of the data to the web that you need to render your templates. Maybe you need to support a protocol that names the function it's calling as part of what it POSTs such as SOAP or XML-RPC.
@@ -33,9 +33,9 @@ Features
 * Can also accept instances of your classes as input
 * Works with TurboGears 1.0
 * MIT license allows for unrestricted use"""
-author = "Kevin Dangoor"
-email = "dangoor+tgwebservices@gmail.com"
+author = "Justin Davis, Kevin Dangoor"
+email = "jedavis83@gmail.com"
 copyright = "Copyright 2006, 2007 Kevin Dangoor, Arbor Networks"
 
-url = "http://tgwebservices.python-hosting.com/"
+url = "http://code.google.com/p/tgws/"
 license = "MIT"
