@@ -9,7 +9,12 @@ import logging
 
 import dispatch
 import cherrypy
-import cElementTree as et
+
+try:
+    from xml.etree import cElementTree as et
+except ImportError:
+    import cElementTree as et
+
 from genshi.builder import tag, Element, Namespace
 
 from turbogears import controllers, expose as tgexpose, error_handler, \
