@@ -267,11 +267,7 @@ def test_call_to_nested_controller():
     cherrypy.root = OuterService("http://foo.bar.baz")
     output = run_soap("innerFooGetFancy")
     print output
-    assert output == """<soapenv:Envelope xmlns="http://foo.bar.bazsoap/types" xmlns:xsd="http://www.w3.org/2001/XMLSchema" xmlns:soapenv="http://schemas.xmlsoap.org/soap/envelope/" xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance">
-    <soapenv:Body>
-        <innerFooGetFancyResponse><result xsi:type="FancyValue"><age xsi:type="xsd:int">42</age><computed xsi:type="xsd:string">Hello!</computed><name xsi:type="xsd:string">Mr. Bean</name></result></innerFooGetFancyResponse>
-    </soapenv:Body>
-</soapenv:Envelope>"""
+    assert """<innerFooGetFancyResponse><result xsi:type="FancyValue"><age xsi:type="xsd:int">42</age><computed xsi:type="xsd:string">Hello!</computed><name xsi:type="xsd:string">Mr. Bean</name></result></innerFooGetFancyResponse>""" in output
 
 def test_documentation_strings():
     cherrypy.root = MyService("http://foo.bar.baz")
